==> server-core-3.6.3-sources.jar: com/xebialabs/deployit/task/ArchivedTaskSearchParameters.java <==
package com.xebialabs.deployit.task;

import java.util.Calendar;

import static com.xebialabs.deployit.checks.Checks.checkNotNull;

public class ArchivedTaskSearchParameters {

    public enum DateRange {
        AFTER, BEFORE, BETWEEN, NONE
    }

    public enum Status {
        COMPLETED, CANCELLED, COMPLETED_AFTER_RETRY, ANY
    }

    protected Calendar startDate;

    protected Calendar endDate;

    protected String executedBy;

    protected String application;

    protected String version;

    protected String environment;

    protected String taskUuid;

    protected DateRange dateRangeSearch = ArchivedTaskSearchParameters.DateRange.NONE;

    protected Status status = ArchivedTaskSearchParameters.Status.ANY;

    public ArchivedTaskSearchParameters() {

    }

    protected ArchivedTaskSearchParameters(ArchivedTaskSearchParameters p) {
        this.startDate = p.startDate;
        this.endDate = p.endDate;
        this.executedBy = p.executedBy;
        this.application = p.application;
        this.version = p.version;
        this.environment = p.environment;
        this.dateRangeSearch = p.dateRangeSearch;
        this.status = p.status;
        this.taskUuid = p.taskUuid;
    }


    public ArchivedTaskSearchParameters executedByUser(String user) {
        this.executedBy = user;
        return this;
    }

    public ArchivedTaskSearchParameters createdBetween(Calendar startDate, Calendar endDate) {
        checkNotNull(startDate, "Start date cannot be null");
        checkNotNull(endDate, "End date cannot be null");
        dateRangeSearch = ArchivedTaskSearchParameters.DateRange.BETWEEN;
        if (startDate.after(endDate)) {
            this.startDate = endDate;
            this.endDate = startDate;
        } else {
            this.startDate = startDate;
            this.endDate = endDate;
        }
        return this;
    }

    public ArchivedTaskSearchParameters createdOnOrBefore(Calendar endDate) {
        checkNotNull(endDate, "End date cannot be null");
        dateRangeSearch = ArchivedTaskSearchParameters.DateRange.BEFORE;
        this.endDate = endDate;
        return this;
    }

    public ArchivedTaskSearchParameters createdOnOrAfter(Calendar startDate) {
        checkNotNull(startDate, "Start date cannot be null");
        dateRangeSearch = ArchivedTaskSearchParameters.DateRange.AFTER;
        this.startDate = startDate;
        return this;
    }

    public ArchivedTaskSearchParameters forApplicationAndVersion(String application, String version) {
        this.application = application;
        this.version = version;
        return this;
    }

    public ArchivedTaskSearchParameters forApplication(String application) {
        return forApplicationAndVersion(application, null);
    }

    public ArchivedTaskSearchParameters toEnvironment(String environment) {
        this.environment = environment;
        return this;
    }

    public ArchivedTaskSearchParameters thatWasCancelled() {
        status = Status.CANCELLED;
        return this;
    }

    public ArchivedTaskSearchParameters thatCompleted() {
        status = Status.COMPLETED;
        return this;
    }

    public ArchivedTaskSearchParameters thatCompletedAfterRetry() {
        status = Status.COMPLETED_AFTER_RETRY;
        return this;
    }

    public ArchivedTaskSearchParameters withUniqueId(String uuid) {
        this.taskUuid = uuid;
        return this;
    }

}

==> server-core-3.7.3-sources.jar: com/xebialabs/deployit/task/ArchivedTaskSearchParameters.java <==
package com.xebialabs.deployit.task;

import java.util.Calendar;

import static com.xebialabs.deployit.checks.Checks.checkNotNull;

public class ArchivedTaskSearchParameters {

    public enum DateRange {
        AFTER, BEFORE, BETWEEN, NONE;
    }

    public enum Status {
        COMPLETED, CANCELLED, COMPLETED_AFTER_RETRY, ANY;
    }

    protected Calendar startDate;

    protected Calendar endDate;

    protected String executedBy;

    protected String application;

    protected String version;

    protected String environment;

    protected String taskUuid;

    protected DateRange dateRangeSearch = ArchivedTaskSearchParameters.DateRange.NONE;

    protected Status status = ArchivedTaskSearchParameters.Status.ANY;

    public ArchivedTaskSearchParameters() {

    }

    protected ArchivedTaskSearchParameters(ArchivedTaskSearchParameters p) {
        this.startDate = p.startDate;
        this.endDate = p.endDate;
        this.executedBy = p.executedBy;
        this.application = p.application;
        this.version = p.version;
        this.environment = p.environment;
        this.dateRangeSearch = p.dateRangeSearch;
        this.status = p.status;
        this.taskUuid = p.taskUuid;
    }


    public ArchivedTaskSearchParameters executedByUser(String user) {
        this.executedBy = user;
        return this;
    }

    public ArchivedTaskSearchParameters createdBetween(Calendar startDate, Calendar endDate) {
        checkNotNull(startDate, "Start date cannot be null");
        checkNotNull(endDate, "End date cannot be null");
        dateRangeSearch = ArchivedTaskSearchParameters.DateRange.BETWEEN;
        if (startDate.after(endDate)) {
            this.startDate = endDate;
            this.endDate = startDate;
        } else {
            this.startDate = startDate;
            this.endDate = endDate;
        }
        return this;
    }

    public ArchivedTaskSearchParameters createdOnOrBefore(Calendar endDate) {
        checkNotNull(endDate, "End date cannot be null");
        dateRangeSearch = ArchivedTaskSearchParameters.DateRange.BEFORE;
        this.endDate = endDate;
        return this;
    }

    public ArchivedTaskSearchParameters createdOnOrAfter(Calendar startDate) {
        checkNotNull(startDate, "Start date cannot be null");
        dateRangeSearch = ArchivedTaskSearchParameters.DateRange.AFTER;
        this.startDate = startDate;
        return this;
    }

    public ArchivedTaskSearchParameters forApplicationAndVersion(String application, String version) {
        this.application = application;
        this.version = version;
        return this;
    }

    public ArchivedTaskSearchParameters forApplication(String application) {
        return forApplicationAndVersion(application, null);
    }

    public ArchivedTaskSearchParameters toEnvironment(String environment) {
        this.environment = environment;
        return this;
    }

    public ArchivedTaskSearchParameters thatWasCancelled() {
        status = Status.CANCELLED;
        return this;
    }

    public ArchivedTaskSearchParameters thatCompleted() {
        status = Status.COMPLETED;
        return this;
    }

    public ArchivedTaskSearchParameters thatCompletedAfterRetry() {
        status = Status.COMPLETED_AFTER_RETRY;
        return this;
    }

    public ArchivedTaskSearchParameters withUniqueId(String uuid) {
        this.taskUuid = uuid;
        return this;
    }

}
